#!/usr/bin/env python

import setuptools

setup_kwargs = { 'author': 'Peter Boin',
  'author_email': 'peter.boin+cqparts@gmail.com',
  'classifiers': [ 'Intended Audience :: Developers',
                   'Intended Audience :: Manufacturing',
                   'Intended Audience :: End Users/Desktop',
                   'Intended Audience :: Science/Research',
                   'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',
                   'Natural Language :: English',
                   'Operating System :: MacOS',
                   'Operating System :: POSIX',
                   'Operating System :: Unix',
                   'Programming Language :: Python',
                   'Programming Language :: Python :: 2',
                   'Programming Language :: Python :: 3',
                   'Topic :: Scientific/Engineering',
                   'Topic :: Multimedia :: Graphics :: 3D Modeling',
                   'Topic :: Multimedia :: Graphics :: 3D Rendering',
                   'Development Status :: 2 - Pre-Alpha'],
  'description': 'Nuts, Bolts and Screws content library for cqparts',
  'install_requires': ['cqparts'],
  'keywords': ['cadquery', 'cad', '3d', 'modeling', 'fasteners'],
  'license': 'GPLv3',
  'long_description': u"\n=========================================\n`cqparts` Content Library : Fasteners\n=========================================\n\nComponents\n-------------------------\n\n**Base Components**\n\nFew of these are useful on their own, they're used to build more complex parts.\n\nHeads\n^^^^^^^^^^^^^^^^^\n\n* Counter-sunk varieties\n* Cylindrical varieties\n* Externally Driven (eg: hex head)\n\n.. image:: https://fragmuffin.github.io/cqparts/media/img/fasteners/heads-assorted.png\n\nDrive Types\n^^^^^^^^^^^^^^^^^\n\n* Cruciform varieties (eg: phillips, frearson)\n* Hex (aka: alan) varieties\n* Square varieties (eg: single, double, triple square)\n* Slotted\n* Tamper Resistant varieties\n\n.. image:: https://fragmuffin.github.io/cqparts/media/img/fasteners/drives-assorted.png\n\nThreads\n^^^^^^^^^^^^^^^^^^\n\nStandard threads included:\n\n* ISO68 (standard for metric bolts)\n* Triangular (eg: for woodscrews)\n* Ball Screw\n\n.. image:: https://fragmuffin.github.io/cqparts/media/img/fasteners/threads-assorted.png\n\nAny custom thread can be built by creating a *profile* as a ``Wire`` from within\nan object inheriting from the base ``Thread`` class.\n(`read more here <https://fragmuffin.github.io/cqparts/doc/api/cqparts_fasteners.solidtypes.threads.html?highlight=build_profile#cqparts_fasteners.solidtypes.threads.base.Thread>`_)\n\n.. note::\n\n    Threads currently bugged by `issue #1 <https://github.com/fragmuffin/cqparts/issues/1>`_.\n\n    Threads are currently simplified to a cylinder until this is fixed.\n\n    Warning when using for 3d printing, threads will not form correctly until the\n    bug is fixed... please ``+1`` the issue if you'd like to use properly formed\n    threads.\n\nMale Fastener Components\n^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^\n\n* Bolts\n* Screws\n\n.. image:: https://fragmuffin.github.io/cqparts/media/img/fasteners/male-assorted.png\n\nFemale Fastener Components\n^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^\n\n* Nuts\n\n.. image:: https://fragmuffin.github.io/cqparts/media/img/fasteners/female-assorted.png\n\nUtilities\n-------------------------\n\nThe ``Fasteners`` utility assembly can be used to automatically apply fasteners\nto arbitrary materials.\n\n\nFor example, with the following 2 detatched blocks:\n\n.. image:: https://fragmuffin.github.io/cqparts/media/img/fasteners/fastener-detatched.png\n\nA ``Fastener`` can be applied to these two blocks to hold them together in a\nvariety of ways, with varied parameters, such as these 2 exmples:\n\n.. image:: https://fragmuffin.github.io/cqparts/media/img/fasteners/fastener-assorted.png\n\nMore detailed examples of customizing a ``Fastener`` are\n`documented here <https://fragmuffin.github.io/cqparts/doc/cqparts_fasteners/>`_.\n\n.. image:: https://fragmuffin.github.io/cqparts/media/img/fasteners/fastener-custom-assorted.png\n\n\nCatalogue(s)\n-------------------------\n\n**BoltDepot**\n\n`boltdepot.com <https://www.boltdepot.com/>`_ has an exceptional website for\ndetails of their products, enough to build 3d models accurate enough for most\napplications.\n\nAt this time, the catalogue you get with this library contains some of the\nproducts for `boltdepot.com <https://www.boltdepot.com/>`_ in the categories:\n\n* Bolts : ``boltdepot-bolts.json``\n* Nuts : ``boltdepot-nuts.json``\n* Woodscrews : ``boltdepot-woodscrews.json``\n\n**Other Suppliers**\n\nWith increased interest in this library I would like to see this list grow, but\nat this time, it's just the catalogues listed above.\n\n\nExamples\n-------------------------\n\nMachine Screw\n^^^^^^^^^^^^^^^^^^^^^^^\n\nWe can create a fastener with many tuned parameters, for this example we'll create\nan M3 machine screw, 4mm long, with a domed cheese head, and a 2mm hex drive::\n\n    from cqparts_fasteners.male import MaleFastenerPart\n\n    screw = MaleFastenerPart(\n        head=('cheese', {\n            'diameter': 4.5,\n            'height': 1.5,\n            'domed': True,\n            'dome_ratio': 0.5,\n        }),\n        drive=('hex', {\n            'depth': 1,\n            'width': 2,\n        }),\n        thread=('iso68', {\n            'diameter': 3,  # M3\n        }),\n        length=4,\n    )\n\n    from cqparts.display import display\n    display(screw)\n\n.. image:: https://fragmuffin.github.io/cqparts/media/img/fasteners/example-screw.png\n\nCatalogue ``Bolt``\n^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^\n\nWith use of a ``JSONCatalogue`` we can search for all fasteners within that\ncatalogue that suit certain parameters, such as length, diameter, anything used\nas a parameter to build the part.\n\nFor this example, we'll explicitly define the product's ``id``, guarenteeing\nonly one result is returned::\n\n    import os\n\n    from cqparts.catalogue import JSONCatalogue\n    import cqparts_fasteners\n\n    catalogue_filename = os.path.join(\n        os.path.dirname(cqparts_fasteners.__file__),\n        'catalogue',\n        'boltdepot-bolts.json',\n    )\n    catalogue = JSONCatalogue(catalogue_filename)\n    item = catalogue.get_query()\n    bolt = catalogue.get(item.id == '221')\n\n    from cqparts.display import display\n    display(bolt)\n\nThis should generate an accurate model for BoltDepot's\n`product #221 <https://www.boltdepot.com/Product-Details.aspx?product=221>`_.\n\n.. image:: https://fragmuffin.github.io/cqparts/media/img/fasteners/example-catalogue.png\n",
  'maintainer': 'Peter Boin',
  'maintainer_email': 'peter.boin+cqparts@gmail.com',
  'name': 'cqparts_fasteners',
  'package_data': { '': ['LICENSE', 'catalogue/*.json']},
  'packages': [ 'cqparts_fasteners',
                'cqparts_fasteners.fasteners',
                'cqparts_fasteners.solidtypes',
                'cqparts_fasteners.utils',
                'cqparts_fasteners.solidtypes.fastener_heads',
                'cqparts_fasteners.solidtypes.screw_drives',
                'cqparts_fasteners.solidtypes.threads'],
  'scripts': [],
  'url': 'https://github.com/fragmuffin/cqparts/tree/master/src/cqparts_fasteners',
  'version': '0.1.0',
  'zip_safe': False}

setuptools.setup(**setup_kwargs)